@@ -163,7 +163,7 @@ PARAM_SIMPLE(
 	"When this parameter is set to a non-zero value, the ban lurker "
 	"continues to work the ban list as usual top to bottom, but when it "
 	"reaches the ban_cutoff-th ban, it treats all objects as if they "
-	"matched a ban and expurges them from cache. As actively used objects "
+	"matched a ban and expunges them from cache. As actively used objects "
 	"get tested against the ban list at request time and thus are likely "
 	"to be associated with bans near the top of the ban list, with "
 	"ban_cutoff, least recently accessed objects (the \"long tail\") are "
@@ -311,6 +311,41 @@ PARAM_SIMPLE(
 	/* flags */	EXPERIMENTAL
 )
 
+PARAM_SIMPLE(
+	/* name */	backend_wait_timeout,
+	/* type */	timeout,
+	/* min */	"0.000",
+	/* max */	NULL,
+	/* def */	"0.000",
+	/* units */	"seconds",
+	/* descr */
+	"When a backend has no connections available for a transaction, "
+	"the transaction can be queued (see backend_wait_limit) to wait for "
+	"a connection.  This is the default time that the transaction will "
+	"wait before giving up. VCL can override this default value for each "
+	"backend.\n\n"
+	"It is strongly advised to never set this higher than a couple of seconds.",
+	/* flags */	EXPERIMENTAL
+)
+
+PARAM_SIMPLE(
+	/* name */	backend_wait_limit,
+	/* type */	uint,
+	/* min */	"0",
+	/* max */	NULL,
+	/* def */	"0",
+	/* units */	NULL,
+	/* descr */
+	"Maximum number of transactions that can queue waiting for a backend "
+	"connection to become available.  This default of 0 (zero) means that "
+	"there is no transaction queueing. VCL can override this default value "
+	"for each backend.\n\n"
+	"Note that this feature must be used with caution, as it can "
+	"cause threads to pile up and increase response times.",
+	/* flags */	EXPERIMENTAL
+)
+
+
 PARAM_SIMPLE(
 	/* name */	cli_limit,
 	/* type */	bytes_u,
@@ -605,11 +640,13 @@ PARAM_SIMPLE(
 	/* units */	"bytes",
 	/* descr */
 	"Maximum number of bytes of HTTP client request we will deal with. "
-	" This is a limit on all bytes up to the double blank line which "
-	"ends the HTTP request.\n"
+	"This is a limit on all bytes up to the double blank line which "
+	"ends the HTTP request. "
 	"The memory for the request is allocated from the client workspace "
 	"(param: workspace_client) and this parameter limits how much of "
-	"that the request is allowed to take up."
+	"that the request is allowed to take up.\n\n"
+	"For HTTP2 clients, it is advertised as MAX_HEADER_LIST_SIZE in "
+	"the initial SETTINGS frame."
 )
 
 PARAM_SIMPLE(
@@ -730,6 +767,22 @@ PARAM_SIMPLE(
 	/* flags */	EXPERIMENTAL
 )
 
+PARAM_SIMPLE(
+	/* name */	panic_buffer,
+	/* type */	bytes_u,
+	/* min */	"4k",
+	/* max */	"10m",
+	/* def */	"64k",
+	/* units */	"bytes",
+	/* descr */
+	"Size of the panic message buffer.\n"
+	"The panic buffer is allocated in the working directory as memory "
+	"shared between the management and worker process, so sufficient "
+	"working directory space should be accounted for if this value is "
+	"adjusted. Panic messages are truncated to the configured size.",
+	/* flags */	MUST_RESTART
+)
+
 PARAM_SIMPLE(
 	/* name */	pcre2_jit_compilation,
 	/* type */	boolean,
@@ -812,7 +865,7 @@ PARAM_SIMPLE(
 	/* descr */
 	"How many parked request we start for each completed request on "
 	"the object.\n"
-	"NB: Even with the implict delay of delivery, this parameter "
+	"NB: Even with the implicit delay of delivery, this parameter "
 	"controls an exponential increase in number of worker threads.",
 	/* flags */	EXPERIMENTAL
 )
@@ -1219,6 +1272,12 @@ PARAM_SIMPLE(
 	/* flags */	WIZARD
 )
 
+#define H2_SETTING_NAME(nm) "SETTINGS_" #nm
+#define H2_SETTING_DESCR(nm)						\
+	"\n\nThe value of this parameter defines " H2_SETTING_NAME(nm)	\
+	" in the initial SETTINGS frame sent to the client when a new "	\
+	"HTTP2 session is established."
+
 PARAM_SIMPLE(
 	/* name */	h2_header_table_size,
 	/* type */	bytes_u,
@@ -1230,6 +1289,7 @@ PARAM_SIMPLE(
 	"HTTP2 header table size.\n"
 	"This is the size that will be used for the HPACK dynamic\n"
 	"decoding table."
+	H2_SETTING_DESCR(HEADER_TABLE_SIZE)
 )
 
 PARAM_SIMPLE(
@@ -1243,6 +1303,7 @@ PARAM_SIMPLE(
 	"HTTP2 Maximum number of concurrent streams.\n"
 	"This is the number of requests that can be active\n"
 	"at the same time for a single HTTP2 connection."
+	H2_SETTING_DESCR(MAX_CONCURRENT_STREAMS)
 )
 
 /* We have a strict min at the protocol default here. This is because we
@@ -1258,7 +1319,8 @@ PARAM_SIMPLE(
 	/* def */	"65535b",
 	/* units */	"bytes",
 	/* descr */
-	"HTTP2 initial flow control window size.",
+	"HTTP2 initial flow control window size."
+	H2_SETTING_DESCR(INITIAL_WINDOW_SIZE)
 )
 
 PARAM_SIMPLE(
@@ -1270,19 +1332,33 @@ PARAM_SIMPLE(
 	/* units */	"bytes",
 	/* descr */
 	"HTTP2 maximum per frame payload size we are willing to accept."
+	H2_SETTING_DESCR(MAX_FRAME_SIZE)
 )
 
 PARAM_SIMPLE(
 	/* name */	h2_max_header_list_size,
 	/* type */	bytes_u,
 	/* min */	"0b",
-	/* max */	NULL,
-	/* def */	"2147483647b",
+	/* max */	"2147483647b", /* NB: not the RFC maximum */
+	/* def */	"0b",
 	/* units */	"bytes",
 	/* descr */
-	"HTTP2 maximum size of an uncompressed header list."
+	"HTTP2 maximum size of an uncompressed header list. This parameter "
+	"is not mapped to " H2_SETTING_NAME(MAX_HEADER_LIST_SIZE) " in the "
+	"initial SETTINGS frame, the http_req_size parameter is instead.\n\n"
+	"The http_req_size advises HTTP2 clients of the maximum size for "
+	"the header list. Exceeding http_req_size results in a reset stream "
+	"after processing the HPACK block to preserve the connection, but "
+	"exceeding h2_max_header_list_size results in the HTTP2 connection "
+	"going away immediately.\n\n"
+	"If h2_max_header_list_size is lower than http_req_size, it has no "
+	"effect, except for the special value zero interpreted as 150% of "
+	"http_req_size."
 )
 
+#undef H2_SETTING_DESCR
+#undef H2_SETTING_NAME
+
 #define H2_RR_INFO \
 	"Changes to this parameter affect the default for new HTTP2 " \
 	"sessions. vmod_h2(3) can be used to adjust it from VCL."
