@@ -46,9 +46,9 @@
 #  error "include vdef.h before vrt.h"
 #endif
 
-#define VRT_MAJOR_VERSION	18U
+#define VRT_MAJOR_VERSION	20U
 
-#define VRT_MINOR_VERSION	0U
+#define VRT_MINOR_VERSION	1U
 
 /***********************************************************************
  * Major and minor VRT API versions.
@@ -57,6 +57,30 @@
  * Whenever something is deleted or changed in a way which is not
  * binary/load-time compatible, increment MAJOR version
  *
+ * 20.1 (2024-11-08)
+ *	VDI_EVENT_SICK added to enum vcl_event_e
+ * 20.0 (2024-09-13)
+ *	struct vrt_backend.backend_wait_timeout added
+ *	struct vrt_backend.backend_wait_limit  added
+ * 19.1 (2024-05-27)
+ *	[cache_varnishd.h] ObjWaitExtend() gained statep argument
+ * 19.0 (2024-03-18)
+ *	[cache.h] (struct req).filter_list renamed to vdp_filter_list
+ *	order of vcl/vmod and director COLD events reversed to directors first
+ *	VRT_u_sess_idle_send_timeout() added
+ *	VRT_u_sess_send_timeout() added
+ *	VRT_u_sess_timeout_idle() added
+ *	VRT_u_sess_timeout_linger() added
+ *	(struct vrt_backend).*_timeout must be initialized to a negative value
+ *	VRT_BACKEND_INIT() helper macro added
+ *	VRT_l_bereq_task_deadline() added
+ *	VRT_r_bereq_task_deadline() added
+ *	VRT_u_bereq_task_deadline() added
+ *	VRT_u_bereq_between_bytes_timeout() added
+ *	VRT_u_bereq_connect_timeout() added
+ *	VRT_u_bereq_first_byte_timeout() added
+ * 18.1 (2023-12-05)
+ *	vbf_objiterate() implementation changed #4013
  * 18.0 (2023-09-15)
  *	[cache_filter.h] struct vdp gained priv1 member
  *	VRT_trace() added
@@ -445,7 +469,7 @@ enum vcl_func_call_e {
 enum vcl_func_fail_e {
 	VSUB_E_OK,
 	VSUB_E_RECURSE, // call would recurse
-	VSUB_E_METHOD	// can not be called from this method
+	VSUB_E_METHOD	// cannot be called from this method
 };
 
 typedef void vcl_func_f(VRT_CTX, enum vcl_func_call_e, enum vcl_func_fail_e *);
@@ -471,7 +495,9 @@ struct vmod_data {
 };
 
 /***********************************************************************
- * VCL events sent to VMODs
+ * Events sent to VMODs and directors:
+ * - VCL: VCL temperature events
+ * - VDI: director events
  */
 
 enum vcl_event_e {
@@ -479,6 +505,8 @@ enum vcl_event_e {
 	VCL_EVENT_WARM,
 	VCL_EVENT_COLD,
 	VCL_EVENT_DISCARD,
+
+	VDI_EVENT_SICK,
 };
 
 typedef int vmod_event_f(VRT_CTX, struct vmod_priv *, enum vcl_event_e);
@@ -570,8 +598,19 @@ struct vrt_endpoint {
 	vtim_dur			connect_timeout;	\
 	vtim_dur			first_byte_timeout;	\
 	vtim_dur			between_bytes_timeout;	\
+	vtim_dur			backend_wait_timeout;	\
 	unsigned			max_connections;	\
-	unsigned			proxy_header;
+	unsigned			proxy_header;		\
+	unsigned			backend_wait_limit;
+
+#define VRT_BACKEND_INIT(be)					\
+	do {							\
+		INIT_OBJ(be, VRT_BACKEND_MAGIC);		\
+		(be)->connect_timeout = -1.0;			\
+		(be)->first_byte_timeout = -1.0;		\
+		(be)->between_bytes_timeout = -1.0;		\
+		(be)->backend_wait_timeout = -1.0;		\
+	} while(0)
 
 #define VRT_BACKEND_HANDLE()			\
 	do {					\
@@ -581,8 +620,10 @@ struct vrt_endpoint {
 		DN(connect_timeout);		\
 		DN(first_byte_timeout);		\
 		DN(between_bytes_timeout);	\
+		DN(backend_wait_timeout);	\
 		DN(max_connections);		\
 		DN(proxy_header);		\
+		DN(backend_wait_limit);		\
 	} while(0)
 
 struct vrt_backend {
